import { VideoWS, VideoWsResult } from '@kevisual/video-tools/src/asr/provider/funasr/ws.ts';
import { BatchSendFiles } from '@kevisual/video-tools/examples/batch-send-files.ts';
import net from 'node:net';
import path from 'node:path';
import natural from 'natural';
import { EventEmitter } from 'eventemitter3';
const videoTestPath = path.join(process.cwd(), 'videos/my_speech_text.wav');
const audioTestPath = path.join(process.cwd(), 'videos/test.mp3');
const name = 'output-1746007775571.mp3';
const videoTestPath2 = path.join(process.cwd(), 'build', name);

const emitter = new EventEmitter();
const url = 'https://funasr.xiongxiao.me';
const local = 'wss://192.168.31.220:10095';
const ws = new VideoWS({
  url: url,
  mode: '2pass',
  wsOptions: {
    rejectUnauthorized: false,
  },
  emitter,
  wav_format: 'wav',
  onConnect: async () => {
    console.log('WebSocket connected');
  },
});

const batchSend = new BatchSendFiles({
  vws: ws,
  // files: [audioTestPath],
  files: [videoTestPath, audioTestPath],
});
batchSend.init();
batchSend.emitter.on('send-done', (data) => {
  const matchText = '在一无所知中，梦里的一天结束了一个新的轮回，便会开始。';
  const textList = data as { file: string; text: string }[];
  for (const item of textList) {
    const getText = item.text || '';
    const distance = natural.JaroWinklerDistance(getText, matchText);
    console.log(`File: ${item.file}, \nText: ${item.text}\nDistance: ${distance}`);
  }
  // console.log('Batch processing done:', data);
});

const server = net.createServer((socket) => {
  socket.on('data', (data) => {
    console.log('data', data);
  });
});
server.listen(10096);
